==> nextcloud-31.0.7-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/sw.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Faili lilipakiwa",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Faili lililopakiwa linazidi kiwango cha juu cha ukubwa wa faili linalielekea katika php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Faili iliyopakiliwa imezidi kiwango cha ukubwa wa faili iliyoelekezwa maalum katika fomu ya HTML",
    "The file was only partially uploaded" : "Faili lilipakiwa kwa sehemu ndogo tu",
    "No file was uploaded" : "Hakuna faili lililopakiwa",
    "Missing a temporary folder" : "Imekosa faili la muda",
    "Could not write file to disk" : "Haikuweza kuandika faili kwenye disk",
    "A PHP extension stopped the file upload" : "Uongezaji wa PHP umesimamisha upakiaji wa faili",
    "No file uploaded or file size exceeds maximum of %s" : "Hakuna faili lililopakiwa au faili lilizidi kiwango cha juu cha %s",
    "New text file" : "New text file",
    "File not found" : "Faili halipatikani",
    "Text" : "Maandishi",
    "Translate" : "Tafsiri",
    "Delete task" : "Futa jukumu",
    "Guest" : "Mgeni",
    "Remove link" : "Ondoa kiungio",
    "Offline" : "Nje ya mtandao",
    "Saving …" : "Inahifadhi...",
    "Saved" : "Imehifadhiwa",
    "Unsaved changes" : "Mabadiliko yasiyohifadhiwa",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Enter" : "Ingiza",
    "Shift" : "Hamisha",
    "Link" : "Kiungio",
    "Action" : "Vitendo",
    "Undo" : "Tendua",
    "Cannot copy, please copy the link manually" : "Haiwezi kunakili, tafadhali nakili kiungio kwa njia za kawaida",
    "Edit link" : "Hariri kiungo",
    "Cancel" : "Cancel",
    "URL" : "Url",
    "Formatting help" : "Uasidizi wa uambizaji",
    "Translation failed" : "Utafsiri umeshindikana",
    "to" : "kwa",
    "Edit" : "Hariri",
    "Source code" : "Msimbo wa chanzo",
    "Done" : "Imefanyika",
    "Details" : "Maelezo ya kina",
    "Ctrl" : "Dhibiti",
    "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
    "Choose" : "Chagua",
    "Choose {file}" : "Chagua {file}",
    "Detect language" : "Lugha iliyotambuliwa",
    "Warning" : "Onyo"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.8-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/text/l10n/sw.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Faili lilipakiwa",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Faili lililopakiwa linazidi kiwango cha juu cha ukubwa wa faili linalielekea katika php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Faili iliyopakiliwa imezidi kiwango cha ukubwa wa faili iliyoelekezwa maalum katika fomu ya HTML",
    "The file was only partially uploaded" : "Faili lilipakiwa kwa sehemu ndogo tu",
    "No file was uploaded" : "Hakuna faili lililopakiwa",
    "Missing a temporary folder" : "Imekosa faili la muda",
    "Could not write file to disk" : "Haikuweza kuandika faili kwenye disk",
    "A PHP extension stopped the file upload" : "Uongezaji wa PHP umesimamisha upakiaji wa faili",
    "No file uploaded or file size exceeds maximum of %s" : "Hakuna faili lililopakiwa au faili lilizidi kiwango cha juu cha %s",
    "New text file" : "New text file",
    "File not found" : "Faili halipatikani",
    "Text" : "Maandishi",
    "Nextcloud Assistant" : "Msaidizi wa Nextcloud",
    "Translate" : "Tafsiri",
    "Delete task" : "Futa jukumu",
    "Reload" : "Reload",
    "Guest" : "Mgeni",
    "Remove link" : "Ondoa kiungio",
    "guest" : "mgeni",
    "Offline" : "Nje ya mtandao",
    "Saving …" : "Inahifadhi...",
    "Saved" : "Imehifadhiwa",
    "Unsaved changes" : "Mabadiliko yasiyohifadhiwa",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Enter" : "Ingiza",
    "Shift" : "Hamisha",
    "Link" : "Kiungio",
    "Action" : "Vitendo",
    "Undo" : "Tendua",
    "Redo" : "Redo",
    "Cannot copy, please copy the link manually" : "Haiwezi kunakili, tafadhali nakili kiungio kwa njia za kawaida",
    "Open link" : "Fungua kiungio",
    "Edit link" : "Hariri kiungo",
    "Cancel" : "Cancel",
    "URL" : "Url",
    "Formatting help" : "Uasidizi wa uambizaji",
    "Translation failed" : "Utafsiri umeshindikana",
    "to" : "kwa",
    "Replace" : "Replace",
    "Upload" : "Pakia",
    "Edit" : "Hariri",
    "Source code" : "Msimbo wa chanzo",
    "Both" : "Both",
    "Done" : "Imefanyika",
    "Lists" : "Lists",
    "Table" : "Jedwali",
    "Details" : "Maelezo ya kina",
    "Ctrl" : "Dhibiti",
    "Option" : "Chaguo",
    "Formatting" : "Formatting",
    "Select file or folder to link to" : "Chagua faili au kisanduku cha kuunga kwa",
    "Choose" : "Chagua",
    "Choose {file}" : "Chagua {file}",
    "Add folder description" : "Add folder description",
    "Detect language" : "Lugha iliyotambuliwa",
    "Info" : "Info",
    "Success" : "Mafanikio",
    "Warning" : "Onyo"
},
"nplurals=2; plural=(n != 1);");
